import os

from cpl_core.configuration import ConfigurationABC
from cpl_core.environment import ApplicationEnvironmentABC
from cpl_core.mailing import EMail, EMailClientABC, EMailClientSettings
from cpl_translation import TranslatePipe
from flask import jsonify

from bot_api.api import Api
from bot_api.configuration.authentication_settings import AuthenticationSettings
from bot_api.logging.api_logger import ApiLogger
from bot_api.model.settings_dto import SettingsDTO
from bot_api.model.version_dto import VersionDTO
from bot_api.route.route import Route


class GuiController:
    BasePath = f"/api/gui"

    def __init__(
        self,
        config: ConfigurationABC,
        env: ApplicationEnvironmentABC,
        logger: ApiLogger,
        t: TranslatePipe,
        api: Api,
        mail_settings: EMailClientSettings,
        mailer: EMailClientABC,
        auth_settings: AuthenticationSettings,
    ):
        self._config = config
        self._env = env
        self._logger = logger
        self._t = t
        self._api = api
        self._mail_settings = mail_settings
        self._mailer = mailer
        self._auth_settings = auth_settings

    @Route.get(f"{BasePath}/api-version")
    async def api_version(self):
        import bot_api

        version = bot_api.version_info
        return VersionDTO(version.major, version.minor, version.micro).to_dict()

    @Route.get(f"{BasePath}/settings")
    @Route.authorize
    async def settings(self):
        import bot_api

        version = bot_api.version_info

        return jsonify(
            SettingsDTO(
                "",
                VersionDTO(version.major, version.minor, version.micro),
                os.path.abspath(os.path.join(self._env.working_directory, "config")),
                "/",
                "/",
                self._auth_settings.token_expire_time,
                self._auth_settings.refresh_token_expire_time,
                self._mail_settings.user_name,
                self._mail_settings.port,
                self._mail_settings.host,
                self._mail_settings.user_name,
                self._mail_settings.user_name,
            ).to_dict()
        )

    @Route.post(f"{BasePath}/send-test-mail/<email>")
    @Route.authorize
    async def send_test_mail(self, email: str):
        mail = EMail()
        mail.add_header("Mime-Version: 1.0")
        mail.add_header("Content-Type: text/plain; charset=utf-8")
        mail.add_header("Content-Transfer-Encoding: quoted-printable")
        mail.add_receiver(email)
        mail.subject = self._t.transform("api.api.test_mail.subject")
        mail.body = self._t.transform("api.api.test_mail.message").format(
            self._env.host_name, self._env.environment_name
        )
        self._mailer.send_mail(mail)
        return "", 200
