from cpl_core.dependency_injection import ServiceProviderABC
from cpl_discord.service import DiscordBotServiceABC

from bot_data.abc.history_table_abc import HistoryTableABC


class ServerHistory(HistoryTableABC):
    def __init__(
        self,
        dc_id: int,
        deleted: bool,
        date_from: str,
        date_to: str,
        id=0,
    ):
        HistoryTableABC.__init__(self)

        self._server_id = id
        self._discord_server_id = dc_id

        self._deleted = deleted
        self._date_from = date_from
        self._date_to = date_to

    @property
    def id(self) -> int:
        return self._server_id

    @property
    def discord_id(self) -> int:
        return self._discord_server_id

    @property
    @ServiceProviderABC.inject
    def name(self, bot: DiscordBotServiceABC) -> str:
        guild = bot.get_guild(self.discord_id)
        return None if guild is None else guild.name

    @property
    @ServiceProviderABC.inject
    def icon_url(self, bot: DiscordBotServiceABC) -> str:
        guild = bot.get_guild(self.discord_id)
        return None if guild is None else guild.icon.url
