from cpl_core.dependency_injection import ServiceProviderABC
from cpl_discord.service import DiscordBotServiceABC

from bot_data.abc.history_table_abc import HistoryTableABC


class ShortRoleNameHistory(HistoryTableABC):
    def __init__(
        self,
        name: str,
        discord_role_id: int,
        server: int,
        deleted: bool,
        date_from: str,
        date_to: str,
        id=0,
    ):
        HistoryTableABC.__init__(self)
        self._id = id
        self._name = name
        self._discord_role_id = discord_role_id
        self._server = server

        self._deleted = deleted
        self._date_from = date_from
        self._date_to = date_to

    @property
    def id(self) -> int:
        return self._id

    @property
    def name(self) -> str:
        return self._name

    @name.setter
    def name(self, value: str):
        self._name = value

    @property
    def role_id(self) -> int:
        return self._discord_role_id

    @role_id.setter
    def role_id(self, value: int):
        self._discord_role_id = value

    @property
    @ServiceProviderABC.inject
    def role_name(self, bot: DiscordBotServiceABC) -> str:
        guild = bot.get_guild(self._server.discord_id)
        return guild.get_role(self.role_id).name

    @property
    def server(self) -> int:
        return self._server
